.. curious documentation master file, created by
   sphinx-quickstart on Fri Dec 30 01:31:23 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to curious's documentation!
===================================

``curious`` is a Python 3.6+ library to interact with the
`Discord <https://discordapp.com>`_ API. It is based on top of `curio
<https://github.com/dabeaz/curio>`_.

Installation
------------

Curious is available on PyPI under ``discord-curious``:

.. code-block:: bash

   $ pip install -U discord-curious


Or for the latest development version:

.. code-block:: bash

   $ pip install -U git+https://github.com/SunDwarf/curious.git#egg=curious

Examples
--------

Examples for how to use the library are available at
https://github.com/SunDwarf/curious/tree/master/examples.


Documentation
~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2
   :caption: Curious

   tutorial/gettingstarted
   tutorial/firstbot

   events

   changelog

API Documentation
~~~~~~~~~~~~~~~~~

The documentation below is automatically generated from the docstrings.

.. toctree::
   :caption: Autosummary
   :maxdepth: 3

   autogen/curious


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
